<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

use Zend\Filter\StringTrim;
use Zend\Form\Element\Password;
use Zend\Form\Element\Submit;
use Zend\Hydrator\ClassMethods;
use Zend\Validator\Identical;
use Zend\Validator\NotEmpty;
use Zend\Validator\Regex;
use Zend\Validator\StringLength;

return [
    'hydrator'     => ClassMethods::class,
    'elements'     => [
        'password'             => [
            'spec' => [
                'name'       => 'password',
                'type'       => Password::class,
                'options'    => [
                    'label' => 'label_password',
                ],
                'attributes' => [
                    'required' => 'required',
                ],
            ],
        ],
        'passwordConfirmation' => [
            'spec' => [
                'name'       => 'passwordConfirmation',
                'type'       => Password::class,
                'options'    => [
                    'label' => 'label_password_confirmation',
                ],
                'attributes' => [
                    'required' => 'required',
                ],
            ],
        ],
        'submit'               => [
            'spec' => [
                'name'       => 'submit',
                'type'       => Submit::class,
                'attributes' => [
                    'value' => 'label_submit',
                ],
            ],
        ],
    ],
    'input_filter' => [
        'password'             => [
            'name'       => 'password',
            'required'   => true,
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'min'      => 8,
                        'max'      => 255,
                        'messages' => [
                            StringLength::TOO_SHORT => 'error_password_length',
                            StringLength::TOO_LONG  => 'error_password_length',
                        ],
                    ],
                ],
                Regex::class        => [
                    'name'    => Regex::class,
                    'options' => [
                        'pattern'  => '/(?:.*[0-9].*[^\w].*|.*[^\w].*[0-9].*)/',
                        'messages' => [
                            Regex::NOT_MATCH => 'error_password_pattern',
                        ],
                    ],
                ],
                Identical::class    => [
                    'name'    => Identical::class,
                    'options' => [
                        'strict'   => false,
                        'token'    => 'passwordConfirmation',
                        'messages' => [
                            Identical::NOT_SAME => 'error_password_confirmation',
                        ],
                    ],
                ],
            ],
        ],
        'passwordConfirmation' => [
            'name'       => 'passwordConfirmation',
            'required'   => true,
            'validators' => [
                NotEmpty::class => [
                    'name' => NotEmpty::class,
                ],
            ],
        ],
        'submit'               => [
            'name'     => 'submit',
            'required' => true,
        ],
    ],
];