<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

use Zend\Filter\StringTrim;
use Zend\Form\Element\Email;
use Zend\Form\Element\Submit;
use Zend\Form\Element\Text;
use Zend\Hydrator\ClassMethods;
use Zend\Validator\EmailAddress;
use Zend\Validator\Identical;
use Zend\Validator\StringLength;

return [
    'hydrator'     => ClassMethods::class,
    'elements'     => [
        'username'             => [
            'spec' => [
                'name'       => 'username',
                'type'       => Email::class,
                'options'    => [
                    'label' => 'label_newusername',
                ],
                'attributes' => [
                    'required' => 'required',
                ],
            ],
        ],
        'usernameConfirmation' => [
            'spec' => [
                'name'       => 'usernameConfirmation',
                'type'       => Text::class,
                'options'    => [
                    'label' => 'label_newusername_confirmation',
                ],
                'attributes' => [
                    'required' => 'required',
                ],
            ],
        ],
        'submit'               => [
            'spec' => [
                'name'       => 'submit',
                'type'       => Submit::class,
                'attributes' => [
                    'value' => 'label_submit',
                ],
            ],
        ],
    ],
    'input_filter' => [
        'username'             => [
            'name'       => 'username',
            'required'   => true,
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 255
                    ],
                ],
                EmailAddress::class => [
                    'name' => EmailAddress::class,
                ],
            ],
        ],
        'usernameConfirmation' => [
            'name'       => 'usernameConfirmation',
            'required'   => true,
            'validators' => [
                Identical::class => [
                    'name'    => Identical::class,
                    'options' => [
                        'strict'   => false,
                        'token'    => 'username',
                        'messages' => [
                            Identical::NOT_SAME => 'error_username_confirmation',
                        ],
                    ],
                ],
            ],
        ],
        'submit'               => [
            'name'       => 'submit',
            'required'   => true,
        ],
    ],
];
